@@ -20,7 +20,9 @@
 
 #define QT_FEATURE_reduce_exports 1
 
-#define QT_FEATURE_no_direct_extern_access -1
+#define QT_FEATURE_no_direct_extern_access 1
+
+#define QT_FEATURE_x86intrin 1
 
 #define QT_FEATURE_sse2 1
 
@@ -112,9 +114,15 @@
 
 #define QT_FEATURE_libudev 1
 
+#define QT_FEATURE_openssl 1
+
 #define QT_FEATURE_dlopen 1
 
 #define QT_FEATURE_relocatable 1
 
 #define QT_FEATURE_intelcet 1
 
+
+#define QT_COPYRIGHT "Copyright (C) 2023 The Qt Company Ltd and other contributors."
+
+#define QT_COPYRIGHT_YEAR "2023"
