@@ -34,6 +34,8 @@
 
 #define QT_FEATURE_cxx2b -1
 
+#define QT_FEATURE_cxx2b -1
+
 #define QT_FEATURE_c99 1
 
 #define QT_FEATURE_c11 1
@@ -42,6 +44,10 @@
 
 #define QT_FEATURE_signaling_nan 1
 
+#define QT_FEATURE_wasm_simd128 -1
+
+#define QT_FEATURE_wasm_exceptions -1
+
 #define QT_FEATURE_zstd 1
 
 #define QT_FEATURE_thread 1
@@ -52,16 +58,23 @@
 
 #define QT_FEATURE_dbus 1
 
+#define QT_FEATURE_openssl_linked 1
 
-#define QT_VERSION_STR "6.4.0"
+#define QT_FEATURE_opensslv11 -1
+
+#define QT_FEATURE_opensslv30 1
+
+
+#define QT_VERSION_STR "6.5.2"
 
 #define QT_VERSION_MAJOR 6
 
-#define QT_VERSION_MINOR 4
+#define QT_VERSION_MINOR 5
 
-#define QT_VERSION_PATCH 0
+#define QT_VERSION_PATCH 2
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_VISIBILITY_AVAILABLE
+#define QT_USE_PROTECTED_VISIBILITY
 #define QT_REDUCE_RELOCATIONS
 #define QT_COMPILER_SUPPORTS_SSE2 1
 #define QT_COMPILER_SUPPORTS_SSE3 1
@@ -86,3 +99,4 @@
 #define QT_COMPILER_SUPPORTS_RDRND 1
 #define QT_COMPILER_SUPPORTS_RDSEED 1
 #define QT_COMPILER_SUPPORTS_SHA 1
+#define QT_LINKED_OPENSSL
